CifFile API documentation

Top

# CifFile module

Show source ≡

    from __future__ import absolute_import
    print("Name is " + repr(__name__))
    from .StarFile import StarError,ReadStar,StarList,apply_line_folding,apply_line_prefix
    from .CifFile_module import CifDic,CifError, CifBlock,ReadCif,ValidCifFile,ValidCifError,Validate,CifFile
    from .CifFile_module import get_number_with_esd,convert_type,validate_report
    from .StarFile import remove_line_prefix,remove_line_folding
    from .StarFile import check_stringiness

## Sub-modules

emapsCifFile.CifFile

emapsCifFile.CifFile_module

emapsCifFile.StarFile

emapsCifFile.StarScan

A tokeniser for Star files

emapsCifFile.TypeContentsParser

emapsCifFile.YappsStarParser_1_0

emapsCifFile.YappsStarParser_1_1

emapsCifFile.YappsStarParser_2_0

emapsCifFile.YappsStarParser_STAR2